'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.darkTheme = exports.createCustomTheme = undefined;

var _ramda = require('ramda');

var _createMuiTheme = require('@material-ui/core/styles/createMuiTheme');

var _createMuiTheme2 = _interopRequireDefault(_createMuiTheme);

var _AppBar = require('./AppBar');

var _Badge = require('./Badge');

var _Button = require('./Button');

var _Drawer = require('./Drawer');

var _Input = require('./Input');

var _InputLabel = require('./InputLabel');

var _Menu = require('./Menu');

var _Paper = require('./Paper');

var _Select = require('./Select');

var _Switch = require('./Switch');

var _Tab = require('./Tabs/Tab');

var _TabIndicator = require('./Tabs/TabIndicator');

var _Table = require('./Table');

var _TextField = require('./TextField');

var _palette = require('./palette');

var _typography = require('./typography');

var _typography2 = _interopRequireDefault(_typography);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var overrides = {
  MuiAppBar: _AppBar.classes,
  MuiBadge: _Badge.classes,
  MuiButton: _Button.classes,
  MuiDrawer: _Drawer.classes,
  MuiInput: _Input.classes,
  MuiInputLabel: _InputLabel.classes,
  MuiMenuItem: _Menu.MenuItemClasses,
  MuiPaper: _Paper.classes,
  MuiSelect: _Select.classes,
  MuiSwitch: _Switch.classes,
  MuiTab: _Tab.classes,
  MuiTabIndicator: _TabIndicator.classes,
  MuiTable: _Table.TableClasses,
  MuiTableBody: _Table.TableBodyClasses,
  MuiTableCell: _Table.TableCellClasses,
  MuiTableHead: _Table.TableHeadClasses,
  MuiTableRow: _Table.TableRowClasses,
  MuiTextField: _TextField.classes
};

var createTheme = function createTheme(paletteType) {
  var palette = (0, _palette.getPaletteInput)(paletteType);

  return (0, _createMuiTheme2.default)({
    overrides: overrides,
    palette: palette,
    typography: _typography2.default
  });
};

var createCustomTheme = exports.createCustomTheme = function createCustomTheme(_ref) {
  var customOverrides = _ref.customOverrides,
      customPalette = _ref.customPalette,
      customTypography = _ref.customTypography;

  var paletteType = customPalette && customPalette.type || _palette.defaultPaletteType;
  var palette = (0, _palette.getPaletteInput)(paletteType);

  if (customPalette && (!customPalette.primary.light || !customPalette.primary.dark)) {
    palette.primary.light = null;
    palette.primary.dark = null;
  }

  var combinedOverrides = customOverrides ? (0, _ramda.mergeDeepRight)(overrides, customOverrides) : overrides;
  var combinedPalette = customPalette ? (0, _ramda.mergeDeepRight)(palette, customPalette) : palette;
  var combinedTypography = customTypography ? (0, _ramda.mergeDeepRight)(_typography2.default, customTypography) : _typography2.default;

  return (0, _createMuiTheme2.default)({
    overrides: combinedOverrides,
    palette: combinedPalette,
    typography: combinedTypography
  });
};

var darkTheme = exports.darkTheme = createTheme('dark');

exports.default = createTheme('light');